@@ -3,6 +3,7 @@ import math, hashlib, requests, json, getopt, sys
 import tempfile
 from tqdm import tqdm
 base_url = "http://202.109.131.111:8022/"
+# base_url = "http://180.114.8.107:8315/"
 
 
 def file_chunk_spilt(path, chunk_size, pi, session):
@@ -34,6 +35,7 @@ def file_chunk_spilt(path, chunk_size, pi, session):
             file_id = res_data["ret_data"]["uuid"]
             uploaded_chunks = res_data["ret_data"]["uploaded_chunks"]
     else:
+        print("something wrong! with upload_post", res.content)
         return "upload error"
     if total_size > chunk_size:
         chunk_number = 0
@@ -66,12 +68,14 @@ def file_chunk_spilt(path, chunk_size, pi, session):
         if res and res.status_code == 200:
             pbar.update()
         else:
+            print("something wrong with upload_post! ", res.content)
             return "upload error"
     # 发送合并分片请求
     res = complete_upload_file(file_id, upload_id, session)
     if res and res.status_code == 200:
         return " upload success"
     else:
+        print("something wrong with complete_upload_file! ", res.content)
         return "upload error"
 
 
@@ -79,9 +83,8 @@ def upload_get(identifier, pi, file_name, total_size, total_chunks, session):
     """
     第一次请求获取upload_id,是否上传过文件，以及上传过的分片id
     """
-    # url = "http://202.109.131.111:8014/prod-api//api/v1.0/files/chunk/upload"
-    # url = "http://202.109.131.111:8018/api/v1.0/files/chunk/upload"
-    # url = "http://172.24.3.80:5000/api/v1.0/files/chunk/upload"
+    # url = "http://202.109.131.111:8022/api/v1.0/files/chunk/upload"
+    # url = "http://180.114.8.107:8315/api/v1.0/files/chunk/upload"
     url = base_url + "api/v1.0/files/chunk/upload"
     data = {
         "identifier": identifier,
@@ -98,9 +101,8 @@ def upload_post(path, file_id, upload_id, chunk_number, current_chunk_size, sess
     """
         上传分片到服务器
     """
-    # url = "http://202.109.131.111:8014/prod-api//api/v1.0/files/chunk/upload"
-    # url = "http://202.109.131.111:8018/api/v1.0/files/chunk/upload"
-    # url = "http://172.24.3.80:5000/api/v1.0/files/chunk/upload"
+    # url = "http://202.109.131.111:8022/api/v1.0/files/chunk/upload"
+    # url = "http://180.114.8.107:8315/api/v1.0/files/chunk/upload"
     url = base_url + "api/v1.0/files/chunk/upload"
     files = {'file': (open(path, 'rb'))}
     data = {
@@ -128,9 +130,8 @@ def complete_upload_file(file_id, upload_id, session):
     """
     合并分片的请求
     """
-    # url = "http://202.109.131.111:8014/prod-api//api/v1.0/files/complete_upload"
-    # url = "http://202.109.131.111:8018/api/v1.0/files/complete_upload"
-    # url = "http://172.24.3.80:5000/api/v1.0/files/complete_upload"
+    # url = "http://202.109.131.111:8022/api/v1.0/files/complete_upload"
+    # url = "http://180.114.8.107:8315/api/v1.0/files/complete_upload"
     url = base_url + "api/v1.0/files/complete_upload"
     data = {
         "file_id": file_id,
@@ -144,39 +145,10 @@ def complete_upload_file(file_id, upload_id, session):
 def main(session, pi, path):
     chunk_size = 104857600  # 100M
     session = session
-    # try:
-    #     options, args = getopt.getopt(argv, "hs:i:p:", ["help", "session=", "id=", "path="])
-    # except getopt.GetoptError:
-    #     sys.exit()
-    # for option, value in options:
-    #     if option in ("-h", "--help"):
-    #         print("-s -----身份凭证")
-    #         print("-i -----目标地址ID")
-    #         print("-p -----文件路径")
-    #         return "help"
-    #     if option in ("-s", "--session"):
-    #         session = "session=" + value
-    #     if option in ("-i", "--id"):
-    #         pi = value
-    #     if option in ("-p", "--path"):
-    #         path = value
-    # if not all([session, pi, path]):
-    #     return "参数不完整"
     result = file_chunk_spilt(path, chunk_size, pi, session)
     return result
 
 
 if __name__ == '__main__':
-    # s = 104857600
-    # path = '/data/hxl/test/下载.jpg'
-    # path = 'C:\\Users\\EDZ\\Desktop\\下载.jpg'
-    # path = 'C:\\Users\\EDZ\\Downloads\\VID_20211219_121111.mp4'
-    # pi = "root"
-    # r = file_chunk_spilt(path, s, pi)
-    # print(r)
-    # session = "session=f0e0035b-8470-4d74-9f5a-3e6d5f9f5b72"
-    # res = main(sys.argv[1:])
-    # re = main(session, pi, path)
-    # print(re)
     print("-----------")
 
